from ParseTree.ParseTree cimport ParseTree
from ParseTree.TreeBank cimport TreeBank

cdef class ParallelTreeBank:

    cdef TreeBank __from_tree_bank
    cdef TreeBank __to_tree_bank

    cpdef removeDifferentTrees(self)
    cpdef int size(self)
    cpdef ParseTree fromTree(self, int index)
    cpdef ParseTree toTree(self, int index)
    cpdef TreeBank getFromTreeBank(self)
    cpdef TreeBank getToTreeBank(self)



cdef class ParallelTreeBank:

    def __init__(self,
                 folder1: str,
                 folder2: str,
                 pattern: str = None):
        self.__from_tree_bank = TreeBank(folder1, pattern)
        self.__to_tree_bank = TreeBank(folder2, pattern)
        self.removeDifferentTrees()

    cpdef removeDifferentTrees(self):
        cdef int i, j
        i = 0
        j = 0
        while i < self.__from_tree_bank.size() and j < self.__to_tree_bank.size():
            if self.__from_tree_bank.get(i).getName() < self.__to_tree_bank.get(j).getName():
                self.__from_tree_bank.removeTree(i)
            elif self.__from_tree_bank.get(i).getName() > self.__to_tree_bank.get(j).getName():
                self.__to_tree_bank.removeTree(j)
            else:
                i = i + 1
                j = j + 1
        while i < self.__from_tree_bank.size():
            self.__from_tree_bank.removeTree(i)
        while j < self.__to_tree_bank.size():
            self.__to_tree_bank.removeTree(j)

    cpdef int size(self):
        return self.__from_tree_bank.size()

    cpdef ParseTree fromTree(self, int index):
        return self.__from_tree_bank.get(index)

    cpdef ParseTree toTree(self, int index):
        return self.__to_tree_bank.get(index)

    cpdef TreeBank getFromTreeBank(self):
        return self.__from_tree_bank

    cpdef TreeBank getToTreeBank(self):
        return self.__to_tree_bank



cdef class ConstituentSpan:

    def __init__(self, constituent: Symbol, start: int, end: int):
        self.__constituent = constituent
        self.__start = start
        self.__end = end

    cpdef int getStart(self):
        return self.__start

    cpdef int getEnd(self):
        return self.__end

    cpdef Symbol getConstituent(self):
        return self.__constituent